@@ -44,12 +44,26 @@ def iter_deletables(tree, unknown=False, ignored=False, detritus=False):
 
 
 def clean_tree(directory, unknown=False, ignored=False, detritus=False, 
-               dry_run=False):
+               dry_run=False, no_prompt=False):
     """Remove files in the specified classes from the tree"""
     tree = WorkingTree.open_containing(directory)[0]
-    deletables = iter_deletables(tree, unknown=unknown, ignored=ignored, 
-                                 detritus=detritus)
-    delete_items(deletables, dry_run=dry_run)
+    tree.lock_read()
+    try:
+        deletables = list(iter_deletables(tree, unknown=unknown,
+            ignored=ignored, detritus=detritus))
+        if len(deletables) == 0:
+            note('Nothing to delete.')
+            return 0
+        if not no_prompt:
+            for path, subp in deletables:
+                print subp
+            val = raw_input('Are you sure you wish to delete these [y/N]?')
+            if val.lower() not in ('y', 'yes'):
+                print 'Canceled'
+                return 0
+        delete_items(deletables, dry_run=dry_run)
+    finally:
+        tree.unlock()
 
 
 def delete_items(deletables, dry_run=False):
