@@ -1,5 +1,5 @@
 # Copyright (C) 2005 Aaron Bentley, 2006 Michael Ellerman
-# <aaron.bentley@utoronto.ca>
+# <aaron@aaronbentley.com>
 #
 #    This program is free software; you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
@@ -15,17 +15,29 @@
 #    along with this program; if not, write to the Free Software
 #    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-class NoPyBaz(Exception):
-    def __init__(self):
-        Exception.__init__(self, "PyBaz is not installed.")
+import os
+
 try:
     from bzrlib.errors import BzrCommandError as CommandError
+    from bzrlib.errors import BzrError
 except ImportError:
     class CommandError(Exception):
         pass
 
-class PatchFailed(Exception):
-    """Failed applying patch!"""
+class PatchFailed(BzrError):
+
+    _fmt = """Patch application failed"""
+
+
+class PatchInvokeError(BzrError):
+
+    _fmt = """Error invoking patch: %(errstr)s%(stderr)s"""
+    internal_error = False
+
+    def __init__(self, e, stderr=''):
+        self.exception = e
+        self.errstr = os.strerror(e.errno)
+        self.stderr = '\n' + stderr
 
 
 class NoColor(Exception):
@@ -49,8 +61,8 @@ class UncommittedCheckout(CommandError):
 class ParentMissingRevisions(CommandError):
     """The parent branch is missing revisions."""
     def __init__(self, parent):
-        CommandError.__init__(self, 
-            "The parent branch %s is missing revisions from this branch." % 
+        CommandError.__init__(self,
+            "The parent branch %s is missing revisions from this branch." %
             parent)
         self.parent = parent
 
@@ -58,3 +70,7 @@ class NoParent(CommandError):
     def __init__(self):
         CommandError.__init__(self, "There is no parent, so deleting the"
                                     " branch could destroy data.")
+
+class ChangedBinaryFiles(BzrError):
+
+    _fmt = 'Changes involve binary files.'
